@@ -18,8 +18,7 @@ class ResourceExistsError(BroadpeakIoApiError):
 
 
 class BroadpeakIoHelperError(Exception):
-    def __init__(self, status_code, message, original_message):
-        self.status_code = status_code
+    def __init__(self, message, original_message=None):
         self.message = message
         self.original_message = original_message
         super().__init__(message)
@@ -30,3 +29,10 @@ class InvalidApiKeyFormat(BroadpeakIoApiError):
         super().__init__(
             403, "The API Key provided has an invalid format", reason, None
         )
+
+
+class InvalidEndpointError(BroadpeakIoApiError):
+    def __init__(self, message, original_message=None):
+        self.message = message
+        self.original_message = original_message
+        super().__init__(message=message, reason=original_message, url=None, status_code=403)
