@@ -1,4 +1,5 @@
 from functools import lru_cache
+import random
 from typing import Dict, List
 from urllib.parse import parse_qs, urlencode, urlparse, urlunparse
 
@@ -8,6 +9,7 @@ from bpkio_api.helpers.codecstrings import CodecStringParser
 from bpkio_api.helpers.handlers.generic import ContentHandler
 from bpkio_api.helpers.times import seconds_to_timecode
 from bpkio_api.models import MediaFormat
+from loguru import logger
 
 
 class HLSHandler(ContentHandler):
@@ -56,7 +58,8 @@ class HLSHandler(ContentHandler):
 
         try:
             return HLSHandler(
-                url=child_url, headers=self.headers,
+                url=child_url,
+                headers=self.headers,
             )
         except IndexError as e:
             raise BroadpeakIoHelperError(
@@ -84,7 +87,8 @@ class HLSHandler(ContentHandler):
         return new_url
 
     @lru_cache()
-    def _fetch_sub(self, uri):
+    def _fetch_sub(self, uri, cache_buster=None):
+        logger.debug(f"Fetching sub-playlist from {uri} with headers {self.headers}")
         try:
             return m3u8.load(
                 uri,
@@ -145,6 +149,11 @@ class HLSHandler(ContentHandler):
         sub = self._fetch_sub(self.document.playlists[0].absolute_uri)
         return len(sub.segments)
 
+    def first_segment_url(self):
+        sub = self._fetch_sub(self.document.playlists[0].absolute_uri, cache_buster=random.random())
+        segment = sub.segments[0]
+        return segment.absolute_uri
+
     def container_format(self):
         """Checks the container format of the segments
 
