@@ -1,8 +1,7 @@
 from typing import List
 
-from pydantic import BaseModel
-
 from bpkio_api.models.common import BaseResource, NamedModel
+from pydantic import BaseModel
 
 
 class SubCategory(BaseModel):
@@ -13,6 +12,10 @@ class SubCategory(BaseModel):
 class CategoryIn(NamedModel):
     subcategories: List[SubCategory] = []
 
+    @property
+    def subcategories_list(self):
+        return ", ".join(f"{sc.key}:{sc.value}" for sc in self.subcategories)
+
 
 class Category(BaseResource, CategoryIn):
     pass
