@@ -6,10 +6,16 @@ from urllib.parse import parse_qs, urlencode, urljoin, urlparse, urlunparse
 
 from bpkio_api.models.common import BaseResource, NamedModel, PropertyMixin
 from bpkio_api.models.MediaFormat import MediaFormat
-from bpkio_api.models.Sources import (AdServerSource, AssetSource, SlateSource,
-                                      SourceSparse)
-from bpkio_api.models.TranscodingProfiles import (TranscodingProfile,
-                                                  TranscodingProfileId)
+from bpkio_api.models.Sources import (
+    AdServerSource,
+    AssetSource,
+    SlateSource,
+    SourceSparse,
+)
+from bpkio_api.models.TranscodingProfiles import (
+    TranscodingProfile,
+    TranscodingProfileId,
+)
 from pydantic import BaseModel, HttpUrl
 
 
@@ -172,9 +178,11 @@ class WithCommonAdInsertionServiceFields(BaseModel):
 
     @property
     def sub_type(self):
+        enabled = []
         for prop in ["vodAdInsertion", "liveAdPreRoll", "liveAdReplacement"]:
             if getattr(self, prop):
-                return prop
+                enabled.append(prop)
+        return " + ".join(enabled)
 
     @property
     def full_url(self):
@@ -218,6 +226,9 @@ class AdInsertionService(
     def type(self):
         return ServiceType.AD_INSERTION
 
+    def main_source(self):
+        return self.source
+
 
 # === CONTENT-REPLACEMENT SERVICE Models ===
 
@@ -239,6 +250,9 @@ class ContentReplacementService(WithCommonServiceFields, ServiceIn):
     def type(self):
         return ServiceType.CONTENT_REPLACEMENT
 
+    def main_source(self):
+        return self.source
+
 
 # === VIRTUAL-CHANNEL SERVICE Models ===
 
@@ -271,6 +285,9 @@ class VirtualChannelService(
     def type(self):
         return ServiceType.VIRTUAL_CHANNEL
 
+    def main_source(self):
+        return self.baseLive
+
 
 # === ADAPTIVE-STREAMING-CDN SERVICE Models ===
 
